@@ -2,11 +2,11 @@ package Shipwright::Source::HTTP;
 
 use warnings;
 use strict;
-use Carp;
 use File::Spec::Functions qw/catfile/;
 use Shipwright::Source::Compressed;
 
 use base qw/Shipwright::Source::Base/;
+use Shipwright::Util;
 
 =head2 run
 
@@ -42,7 +42,7 @@ sub _run {
         $self->_lwp_get($source);
     }
     else {
-        confess "invalid source: $source";
+        confess_or_die "invalid source: $source";
     }
     return 1;
 }
