@@ -2,42 +2,79 @@ package Shipwright::Util;
 
 use warnings;
 use strict;
-use Carp;
+use Shipwright::Util;
 use IPC::Run3;
 use File::Spec::Functions qw/catfile catdir splitpath splitdir tmpdir rel2abs/;
 use Cwd qw/abs_path getcwd/;
-
+use Carp;
 use Shipwright;    # we need this to find where Shipwright.pm lives
 use YAML::Tiny;
+use base 'Exporter';
+our @EXPORT = qw/load_yaml load_yaml_file dump_yaml dump_yaml_file run_cmd
+select_fh shipwright_root share_root user_home confess_or_die
+shipwright_user_root parent_dir find_module/;
 
 our ( $SHIPWRIGHT_ROOT, $SHARE_ROOT );
 
-BEGIN {
-    *Load     = *YAML::Tiny::Load;
-    *Dump     = *YAML::Tiny::Dump;
-    *LoadFile = *YAML::Tiny::LoadFile;
-    *DumpFile = *YAML::Tiny::DumpFile;
+sub load_yaml {
+    goto &YAML::Tiny::Load;
 }
 
+sub load_yaml_file {
+    goto &YAML::Tiny::LoadFile;
+}
+
+sub dump_yaml {
+    goto &YAML::Tiny::Dump;
+}
+
+sub dump_yaml_file {
+    goto &YAML::Tiny::DumpFile;
+}
+
+
 =head1 LIST
 
-=head2 YAML
+=head2 General Helpers
 
-=head3 Load, LoadFile, Dump, DumpFile
+=head3 load_yaml, load_yaml_file, dump_yaml, dump_yaml_file
 
-Load, LoadFile, Dump and DumpFile are just dropped in from L<YAML> or L<YAML::Syck>.
+they are just dropped in from YAML::Tiny
+
+=head3 confess_or_die
+
+=cut
+
+sub confess_or_die {
+    if ( $ENV{SHIPWRIGHT_DEVEL} ) {
+        goto &confess;
+    }
+    else {
+        die @_,"\n";
+    }
+}
+
+=head3 parent_dir
+
+return the dir's parent dir, the arg must be a dir path
+
+=cut
+
+sub parent_dir {
+    my $dir  = shift;
+    my @dirs = splitdir($dir);
+    pop @dirs;
+    return catdir(@dirs);
+}
 
 
-=head2 GENERAL HELPERS
-
-=head3 run
+=head3 run_cmd
 
 a wrapper of run3 sub in IPC::Run3.
 
 =cut
 
-sub run {
-    my $class          = shift;
+sub run_cmd {
     my $cmd            = shift;
     my $ignore_failure = shift;
 
@@ -56,9 +93,9 @@ sub run {
 
     my ( $out, $err );
     $log->info( "run cmd: " . join ' ', @$cmd );
-    Shipwright::Util->select('null');
+    select_fh('null');
     run3( $cmd, undef, \$out, \$err );
-    Shipwright::Util->select('stdout');
+    select_fh('stdout');
 
     $log->debug("run output:\n$out") if $out;
     $log->error("run err:\n$err")   if $err;
@@ -77,7 +114,7 @@ sub run {
             }
 
             my $cwd = getcwd;
-            confess <<"EOF";
+            confess_or_die <<"EOF";
 command failed: @$cmd
 \$?: $?
 cwd: $cwd
@@ -93,7 +130,7 @@ EOF
 
 }
 
-=head3 select
+=head3 select_fh
 
 wrapper for the select in core
 
@@ -109,26 +146,25 @@ open $null_fh, '>', '/dev/null';
 $cpan_log_path = catfile( tmpdir(), 'shipwright_cpan.log');
 
 open $cpan_fh, '>>', $cpan_log_path;
-$stdout_fh = CORE::select();
+$stdout_fh = select;
 
-sub select {
-    my $self = shift;
+sub select_fh {
     my $type = shift;
 
     if ( $type eq 'null' ) {
-        CORE::select $null_fh;
+        select $null_fh;
     }
     elsif ( $type eq 'stdout' ) {
-        CORE::select $stdout_fh;
+        select $stdout_fh;
     }
     elsif ( $type eq 'cpan' ) {
         warn "CPAN related output will be at $cpan_log_path\n"
           unless $cpan_fh_flag;
         $cpan_fh_flag = 1;
-        CORE::select $cpan_fh;
+        select $cpan_fh;
     }
     else {
-        confess "unknown type: $type";
+        confess_or_die "unknown type: $type";
     }
 }
 
@@ -138,10 +174,10 @@ Takes perl modules name space and name of a module in the space.
 Finds and returns matching module name using case insensitive search, for
 example:
 
-    Shipwright::Util->find_module('Shipwright::Backend', 'svn');
+    find_module('Shipwright::Backend', 'svn');
     # returns 'Shipwright::Backend::SVN'
 
-    Shipwright::Util->find_module('Shipwright::Backend', 'git');
+    find_module('Shipwright::Backend', 'git');
     # returns 'Shipwright::Backend::Git'
 
 Returns undef if there is no module matching criteria.
@@ -149,7 +185,6 @@ Returns undef if there is no module matching criteria.
 =cut
 
 sub find_module {
-    my $self = shift;
     my $space = shift;
     my $name = shift;
 
@@ -174,13 +209,10 @@ Uses %INC to figure out where Shipwright.pm is.
 =cut
 
 sub shipwright_root {
-    my $self = shift;
-
     unless ($SHIPWRIGHT_ROOT) {
         my $dir = ( splitpath( $INC{"Shipwright.pm"} ) )[1];
         $SHIPWRIGHT_ROOT = rel2abs($dir);
     }
-
     return ($SHIPWRIGHT_ROOT);
 }
 
@@ -192,10 +224,8 @@ currently only used to store the initial files in project.
 =cut
 
 sub share_root {
-    my $self = shift;
-
     unless ($SHARE_ROOT) {
-        my @root = splitdir( $self->shipwright_root );
+        my @root = splitdir( shipwright_root() );
 
         if (   $root[-2] ne 'blib'
             && $root[-1] eq 'lib'
@@ -227,7 +257,7 @@ sub user_home {
 
     my $home = eval { (getpwuid $<)[7] };
     if ( $@ ) {
-        confess "can't find user's home, please set it by env HOME";    
+        confess_or_die "can't find user's home, please set it by env HOME";    
     }
     else {
         return $home;
@@ -246,20 +276,6 @@ sub shipwright_user_root {
     return $ENV{SHIPWRIGHT_USER_ROOT} || catdir( user_home, '.shipwright' );
 }
 
-=head3 parent_dir
-
-return the dir's parent dir, the arg must be a dir path
-
-=cut
-
-sub parent_dir {
-    my $self = shift;
-    my $dir  = shift;
-    my @dirs = splitdir($dir);
-    pop @dirs;
-    return catdir(@dirs);
-}
-
 1;
 
 __END__
